# (L)OST SPC

Refer to the [full documentation](https://drazhar.github.io/lost_spc/) for more details.

## Development

### mkdocs

To run mkdocs locally, you have to run the following command in the terminal:

```bash
mkdocs serve
```

### pytest

To execute unit tests from the `tests` folder and the examples from the docstrings:

```bash
pytest
```
